@@ -8,7 +8,7 @@ Combine = merge/join
 ########################################################################################################################
 
 from rdkit import Chem
-from rdkit.Chem import AllChem
+from rdkit.Chem import AllChem, rdmolops
 
 from ._collapse_ring import _MonsterRing
 from ._base import _MonsterBase
@@ -78,4 +78,5 @@ class _MonsterCombine(_MonsterRing, _MonsterMerge):
             self.positioned_mol = recto.mol
         else: # the molecule is still nasty. Getting largest.
             self.positioned_mol = sorted(frags, key=lambda mol: mol.GetNumAtoms(), reverse=True)[0]
+        Chem.rdmolops.AssignStereochemistryFrom3D(self.positioned_mol)
         self.keep_copies(recto.modifications, 'fixed')
